@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The utility API of Tokyo Promenade
- *                                                      Copyright (C) 2008-2009 Mikio Hirabayashi
+ *                                                      Copyright (C) 2008-2010 Mikio Hirabayashi
  * This file is part of Tokyo Promenade.
  * This program is free software: you can redistribute it and/or modify it under the terms of
  * the GNU General Public License as published by the Free Software Foundation, either version
@@ -377,11 +377,11 @@ void wikitotext(TCXSTR *rbuf, const char *str){
       line += 3;
       while(*line != '\0'){
         switch(*line){
-        case '{': tcxstrprintf(sep, "%c", '}'); break;
-        case '[': tcxstrprintf(sep, "%c", ']'); break;
-        case '<': tcxstrprintf(sep, "%c", '>'); break;
-        case '(': tcxstrprintf(sep, "%c", ')'); break;
-        default: tcxstrcat(sep, line, 1); break;
+          case '{': tcxstrprintf(sep, "%c", '}'); break;
+          case '[': tcxstrprintf(sep, "%c", ']'); break;
+          case '<': tcxstrprintf(sep, "%c", '>'); break;
+          case '(': tcxstrprintf(sep, "%c", ')'); break;
+          default: tcxstrcat(sep, line, 1); break;
         }
         line++;
       }
@@ -740,11 +740,11 @@ void wikitohtml(TCXSTR *rbuf, const char *str, const char *id, const char *buri,
       line += 3;
       while(*line != '\0'){
         switch(*line){
-        case '{': tcxstrprintf(sep, "%c", '}'); break;
-        case '[': tcxstrprintf(sep, "%c", ']'); break;
-        case '<': tcxstrprintf(sep, "%c", '>'); break;
-        case '(': tcxstrprintf(sep, "%c", ')'); break;
-        default: tcxstrcat(sep, line, 1); break;
+          case '{': tcxstrprintf(sep, "%c", '}'); break;
+          case '[': tcxstrprintf(sep, "%c", ']'); break;
+          case '<': tcxstrprintf(sep, "%c", '>'); break;
+          case '(': tcxstrprintf(sep, "%c", ')'); break;
+          default: tcxstrcat(sep, line, 1); break;
         }
         line++;
       }
@@ -1027,21 +1027,21 @@ void wikitohtmlinline(TCXSTR *rbuf, const char *line, const char *buri, const ch
         line = pv + 2;
       } else {
         switch(*line){
-        case '&': tcxstrcat(rbuf, "&amp;", 5); break;
-        case '<': tcxstrcat(rbuf, "&lt;", 4); break;
-        case '>': tcxstrcat(rbuf, "&gt;", 4); break;
-        case '"': tcxstrcat(rbuf, "&quot;", 6); break;
-        default: tcxstrcat(rbuf, line, 1); break;
+          case '&': tcxstrcat(rbuf, "&amp;", 5); break;
+          case '<': tcxstrcat(rbuf, "&lt;", 4); break;
+          case '>': tcxstrcat(rbuf, "&gt;", 4); break;
+          case '"': tcxstrcat(rbuf, "&quot;", 6); break;
+          default: tcxstrcat(rbuf, line, 1); break;
         }
         line++;
       }
     } else {
       switch(*line){
-      case '&': tcxstrcat(rbuf, "&amp;", 5); break;
-      case '<': tcxstrcat(rbuf, "&lt;", 4); break;
-      case '>': tcxstrcat(rbuf, "&gt;", 4); break;
-      case '"': tcxstrcat(rbuf, "&quot;", 6); break;
-      default: tcxstrcat(rbuf, line, 1); break;
+        case '&': tcxstrcat(rbuf, "&amp;", 5); break;
+        case '<': tcxstrcat(rbuf, "&lt;", 4); break;
+        case '>': tcxstrcat(rbuf, "&gt;", 4); break;
+        case '"': tcxstrcat(rbuf, "&quot;", 6); break;
+        default: tcxstrcat(rbuf, line, 1); break;
       }
       line++;
     }
@@ -1052,12 +1052,16 @@ void wikitohtmlinline(TCXSTR *rbuf, const char *line, const char *buri, const ch
 /* Simplify a date string. */
 char *datestrsimple(char *str){
   assert(str);
-  tcstrsubchr(str, "-T", "/ ");
-  char *pv = strchr(str, '+');
-  if(!pv) pv = strchr(str, 'Z');
-  if(pv) *pv = '\0';
-  pv = strrchr(str, ':');
-  if(pv) *pv = '\0';
+  char *pv = str;
+  while(*pv > '\0' && *pv <= ' '){
+    pv++;
+  }
+  int len = strlen(pv);
+  if(len <= 16 || pv[4] != '-' || pv[7] != '-' || pv[10] != 'T' || pv[13] != ':') return pv;
+  pv[4] = '/';
+  pv[7] = '/';
+  pv[10] = ' ';
+  pv[16] = '\0';
   return str;
 }
 
