@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The Web interface of Tokyo Promenade
- *                                                      Copyright (C) 2008-2009 Mikio Hirabayashi
+ *                                                      Copyright (C) 2008-2010 Mikio Hirabayashi
  * This file is part of Tokyo Promenade.
  * This program is free software: you can redistribute it and/or modify it under the terms of
  * the GNU General Public License as published by the Free Software Foundation, either version
@@ -218,21 +218,21 @@ static int realmain(int argc, char **argv){
 /* show the error page */
 static void showerror(int code, const char *msg){
   switch(code){
-  case 400:
-    printf("Status: %d Bad Request\r\n", code);
-    break;
-  case 404:
-    printf("Status: %d File Not Found\r\n", code);
-    break;
-  case 413:
-    printf("Status: %d Request Entity Too Large\r\n", code);
-    break;
-  case 500:
-    printf("Status: %d Internal Server Error\r\n", code);
-    break;
-  default:
-    printf("Status: %d Error\r\n", code);
-    break;
+    case 400:
+      printf("Status: %d Bad Request\r\n", code);
+      break;
+    case 404:
+      printf("Status: %d File Not Found\r\n", code);
+      break;
+    case 413:
+      printf("Status: %d Request Entity Too Large\r\n", code);
+      break;
+    case 500:
+      printf("Status: %d Internal Server Error\r\n", code);
+      break;
+    default:
+      printf("Status: %d Error\r\n", code);
+      break;
   }
   printf("Content-Type: text/plain; charset=UTF-8\r\n");
   printf("\r\n");
@@ -331,7 +331,7 @@ static void dosession(TCMPOOL *mpool){
   // read query parameters
   rp = getenv("CONTENT_LENGTH");
   bool post = false;
-  if(rp){
+  if(rp && *rp != '\0'){
     int clen = tcatoi(rp);
     if(clen > g_recvmax){
       showerror(413, "The entity body was too long.");
@@ -344,10 +344,9 @@ static void dosession(TCMPOOL *mpool){
     }
     tcwwwformdecode2(cbuf, clen, getenv("CONTENT_TYPE"), params);
     post = true;
-  } else {
-    const char *query = getenv("QUERY_STRING");
-    if(query) tcwwwformdecode(query, params);
   }
+  rp = getenv("QUERY_STRING");
+  if(rp) tcwwwformdecode(rp, params);
   rp = getenv("HTTP_COOKIE");
   if(rp) tcwwwformdecode(rp, params);
   const char *p_user = tcstrskipspc(tcmapget4(params, "user", ""));
@@ -1061,6 +1060,7 @@ static void dosession(TCMPOOL *mpool){
         tcmapput2(vars, "view", "empty");
       }
     } else {
+      tcmapprintf(vars, "hitnum", "%d", rnum);
       TCLIST *arts = tcmpoollistnew(mpool);
       for(int i = 0; i < rnum && i < max; i++){
         int64_t id = tcatoi(tclistval2(res, i));
@@ -1116,7 +1116,9 @@ static void dosession(TCMPOOL *mpool){
       if(tcmapget2(vars, "prev") || tcmapget2(vars, "next")) tcmapput2(vars, "page", "true");
       tcmapputlist(vars, "arts", arts);
     }
-    if(*p_cond == '\0'){
+    if(*p_cond != '\0'){
+      tcmapprintf(vars, "hitnum", "%d", rnum);
+    } else {
       res = tcmpoollistnew(mpool);
       char numbuf[NUMBUFSIZ];
       tcdatestrwww(now, INT_MAX, numbuf);
@@ -1790,7 +1792,7 @@ static bool doupdatecmd(TCMPOOL *mpool, const char *mode, const char *baseurl, c
     wikidump(obuf, ocols);
   }
   char *opath = tcmpoolpushptr(mpool, tcsprintf("%s/tmp-%lld-%lld-%s-old.tpw", base,
-                                          (long long)id, (long long)ts, mode));
+                                                (long long)id, (long long)ts, mode));
   if(!tcwritefile(opath, tcxstrptr(obuf), tcxstrsize(obuf))) err = true;
   char idbuf[NUMBUFSIZ];
   sprintf(idbuf, "%lld", (long long)id);
